==> r-mail-1.0.0.zip: r-mail-1.0.0/carnet_adresses/export_carte.php <==
<?

session_start ();

if (!empty ($export)) {

	if (isset ($base_mysql)) {

	$connect=@mysql_connect("$base_mysql", "$user_mysql", "$password_mysql")
	or die("Impossible de se connecter  la base MySQL");

	mysql_select_db ($nom_base_mysql);

	$recup_nom=mysql_query ("select nom from $login where auto_inc='$export'");

	$nom=mysql_fetch_row ($recup_nom);

	$recup=mysql_query ("select nom,prenom,surnom,adresse,code_postal,ville,pays,".
	"tel_fixe,tel_mobile,fax,mail,societe,notes from $login where auto_inc=$export");

	$chemin="$temp_dir/$login";

		if (!is_dir ("$chemin")) {
		@mkdir ("$chemin", 0700);
		}

	$chaque_valeur=@mysql_fetch_row ($recup);

		if (file_exists ("$chemin/$nom[0].rma")) {
		@unlink ("$chemin/$nom[0].rma");
		}

	$ouv=@fopen ("$chemin/$nom[0].rma", "a+b");

		for ($c=0;$c<13;$c++) {
		$enc=@fwrite ($ouv, "$chaque_valeur[$c]\r\n");
		}

	@fclose ($ouv);

	mysql_close ($connect);

	header ("location: export_carte.php?envoi=1");

	} else {

	if (!isset ($auth)) {

	$connect_ldap=@ldap_connect ($annuaire_ldap, $port_ldap)
	or die ("Impossible de se connecter  l'annuaire ldap");

	//Chemin des utilisateurs et des carnets d'adresses
	$chemin_login="cn=$login,$bind_dn";
	$chemin_carnet_adresses="ou=$carnet_adresse,$bind_adresses";

	if (@ldap_bind($connect_ldap, $chemin_login, $password)!=false) {
	} else {

	@ldap_set_option($connect_ldap,LDAP_OPT_PROTOCOL_VERSION,3);

		if (@ldap_bind($connect_ldap, $chemin_login, $password)!=false) {
		} else {
		header ("location: export_carte.php?auth=1");
		}
	}

	$cherche=@ldap_search($connect_ldap, "ou=rep_$login,$chemin_carnet_adresses", "(mail=$export)");
	$info=@ldap_get_entries($connect_ldap, $cherche);

	$chemin="$temp_dir/$login";

		if (!is_dir ("$chemin")) {
		@mkdir ("$chemin", 0700);
		}

		if (file_exists ("$chemin/".$info[0][sn][0].".rma")) {
		@unlink ("$chemin/".$info[0][sn][0].".rma");
		}

	$tab=array (sn,givenname,nickname,postaladdress,postalcode,l,c,telephonenumber,mobile,facsimiletelephonenumber,mail,organizationalstatus);

	$ouv=@fopen ("$chemin/".$info[0][sn][0].".rma", "a+b");

		for ($c=0;$c<13;$c++) {
			if ($c==12) {
				for ($d=0;$d<$info[0][description]["count"];$d++) {
					if ($info[0][description][$d]!="\r") {
					$enc=@fwrite ($ouv, "".$info[0][description][$d]."\n");
					}
				}
			}
		$enc=@fwrite ($ouv, "".$info[0][$tab[$c]][0]."\n");
		}

	@fclose ($ouv);

	@ldap_close ($connect_ldap);

	header ("location: export_carte.php?envoi=1");
	
	}

	}

}

?>

<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<title>R-MAIL V.1.0.0 - Export carte</title>
</head>
<body bgcolor="#ffffff" text="#000000" link="#000000" vlink="#000000" alink="#000000">
<form>

<table border=0 width=100% cellspacing=0>
<tr><td align=middle bgcolor="#1FCBCB">
<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB" align=middle>
<font size=4>Export carte</font>
</td></tr>
</table>

<font size=1>&#160;</font>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td align=middle>

	<table border=0 width=65% bgcolor="#1FCBCB" cellpadding=5 >
	<tr><td>

		<table border=0 bgcolor="#9AC6CB" width=100% cellspacing=0>
		<tr><td>
		<font size=1>&#160;</font>
		</td></tr>

		<tr><td align=middle>
		Choisissez la carte  exporter
		</td></tr>

		<tr><td>
		<font size=1>&#160;</font>
		</td></tr>

		<tr><td width=40% align=middle>
		<select name="export">
		<option value=""></option>

		<?
		
		if (isset ($base_mysql)) {

		$connect=@mysql_connect("$base_mysql", "$user_mysql", "$password_mysql")
		or die("Impossible de se connecter  la base MySQL");

		mysql_select_db ($nom_base_mysql);

		$requete=mysql_query ("select auto_inc, mail from $login");

		$nbre_lignes=mysql_num_rows ($requete);

		for ($a=0;$a<$nbre_lignes;$a++) {
		$tri=mysql_fetch_row ($requete);
		echo "<option value=\"$tri[0]\">$tri[1]</option>";
		}

		mysql_close ($connect);
		
		} else {

		if (!isset ($auth)) {

		$connect_ldap=@ldap_connect ($annuaire_ldap, $port_ldap)
		or die ("Impossible de se connecter  l'annuaire ldap");

		//Chemin des utilisateurs et des carnets d'adresses
		$chemin_login="cn=$login,$bind_dn";
		$chemin_carnet_adresses="ou=$carnet_adresse,$bind_adresses";

		if (@ldap_bind($connect_ldap, $chemin_login, $password)!=false) {
		} else {

		@ldap_set_option($connect_ldap,LDAP_OPT_PROTOCOL_VERSION,3);

			if (@ldap_bind($connect_ldap, $chemin_login, $password)!=false) {
			} else {
			echo "<tr><td colspan=2 align=middle>\nImpossible de s'authentifier\n</td></tr>";
			}
		}

		$cherche=@ldap_search($connect_ldap, "ou=rep_$login,$chemin_carnet_adresses", "(sn=*)", array (mail));
		$info=@ldap_get_entries($connect_ldap, $cherche);

		for ($b=0;$b<count ($info)-1;$b++) {
		echo "<option value=\"".$info[$b][mail][0]."\">".$info[$b][mail][0]."</option>";
		}

		@ldap_close ($connect_ldap);
		}
		}

		?>

		</select>
		</td></tr>

		<tr><td>
		<font size=1>&#160;</font>
		</td></tr>

		<tr><td align=middle>
		<input type="submit" value="envoi">
		</td></tr>
		
		<?

		if (isset ($envoi)) {
		echo "<tr><td>\n<font size=1>&#160;</font>\n</td></tr>";
		echo "<tr><td>\nExporter une nouvelle carte ou ".
		"<a href=\"#\" onClick=\"open('../gestion_messages/nouveau_message.php?carte=1',".
		"'', 'height=550, width=650, scrollbars=yes, resizable=yes')\">".
		"envoyer la ou les exportations</a>\n</td></tr>";
		echo "<tr><td>\n<font size=1>&#160;</font>\n</td></tr>";
		} elseif (isset ($auth)) {
		echo "<tr><td align=middle>\nImpossible de s'authentifier\n</td></tr>";
		}

		?>

		</table>

	</td></tr>
	</table>
	
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
<br>
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td align=middle bgcolor="#1FCBCB">
<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>
</td></tr>
</table>

</form>
</body>
</html>

==> r-mail-1.0.2.zip: r-mail.1.0.2/carnet_adresses/export_carte.php <==
<?

session_start ();

include '../langage.php';

$login = $_SESSION ["login"];
$temp_dir = $_SESSION ["temp_dir"];

if (!empty ($_GET ["export"])) {

	$export = $_GET ["export"];
	
	if (isset ($_SESSION ["base_mysql"])) {

	$connect=@mysql_connect($_SESSION ["base_mysql"], $_SESSION ["user_mysql"], $_SESSION ["password_mysql"])
	or die($page_export[$_SESSION ["lang"]][0]);

	mysql_select_db ($_SESSION ["nom_base_mysql"]);

	$recup_nom=mysql_query ("select nom from $login where auto_inc='$export'");

	$nom=mysql_fetch_row ($recup_nom);

	$recup=mysql_query ("select nom,prenom,surnom,adresse,code_postal,ville,pays,".
	"tel_fixe,tel_mobile,fax,mail,societe,notes from $login where auto_inc=$export");

	$chemin="$temp_dir/$login";

		if (!is_dir ("$chemin")) {
		@mkdir ("$chemin", 0700);
		}

	$chaque_valeur=@mysql_fetch_row ($recup);

		if (file_exists ("$chemin/$nom[0].rma")) {
		@unlink ("$chemin/$nom[0].rma");
		}

	$ouv=@fopen ("$chemin/$nom[0].rma", "a+b");

		for ($c=0;$c<13;$c++) {
		$enc=@fwrite ($ouv, "$chaque_valeur[$c]\r\n");
		}

	@fclose ($ouv);

	mysql_close ($connect);

	header ("location: export_carte.php?envoi=1");

	} else {

	if (!isset ($_GET ["auth"])) {
	
	$export = $_GET ["export"];
	
	$connect_ldap=@ldap_connect ($_SESSION ["annuaire_ldap"], $_SESSION ["port_ldap"])
	or die ($page_export[$_SESSION ["lang"]][1]);
	
	$bind_dn = $_SESSION ["bind_dn"];
	$carnet_adresse = $_SESSION ["carnet_adresse"];
	$bind_adresses = $_SESSION ["bind_adresses"];

	//Chemin des utilisateurs et des carnets d'adresses
	$chemin_login="cn=$login,$bind_dn";
	$chemin_carnet_adresses="ou=$carnet_adresse,$bind_adresses";

	if (@ldap_bind($connect_ldap, $chemin_login, $_SESSION ["password"])!=false) {
	} else {

	@ldap_set_option($connect_ldap,LDAP_OPT_PROTOCOL_VERSION,3);

		if (@ldap_bind($connect_ldap, $chemin_login, $_SESSION ["password"])!=false) {
		} else {
		header ("location: export_carte.php?auth=1");
		}
	}

	$cherche=@ldap_search($connect_ldap, "ou=rep_$login,$chemin_carnet_adresses", "(mail=$export)");
	$info=@ldap_get_entries($connect_ldap, $cherche);

	$chemin="$temp_dir/$login";

		if (!is_dir ("$chemin")) {
		@mkdir ("$chemin", 0700);
		}

		if (file_exists ("$chemin/".$info[0][sn][0].".rma")) {
		@unlink ("$chemin/".$info[0][sn][0].".rma");
		}

	$tab=array ("sn","givenname","nickname","postaladdress","postalcode","l","c","telephonenumber","mobile","facsimiletelephonenumber","mail","organizationalstatus");

	$ouv=@fopen ("$chemin/".$info[0][sn][0].".rma", "a+b");

		for ($c=0;$c<13;$c++) {
			if ($c==12) {
				for ($d=0;$d<$info[0][description]["count"];$d++) {
					if ($info[0][description][$d]!="\r") {
					$enc=@fwrite ($ouv, "".$info[0][description][$d]."\n");
					}
				}
			}
		$enc=@fwrite ($ouv, "".$info[0][$tab[$c]][0]."\n");
		}

	@fclose ($ouv);

	@ldap_close ($connect_ldap);

	header ("location: export_carte.php?envoi=1");
	
	}

	}

}

?>

<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<title>R-MAIL - <? echo $page_export[$_SESSION ["lang"]][2]; ?></title>
</head>
<body bgcolor="#ffffff" text="#000000" link="#000000" vlink="#000000" alink="#000000">
<form>

<table border=0 width=100% cellspacing=0>
<tr><td align=middle bgcolor="#1FCBCB">
<font size=5><b><u>R-MAIL</u></b></font>
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB" align=middle>
<font size=4><? echo $page_export[$_SESSION ["lang"]][2]; ?></font>
</td></tr>
</table>

<font size=1>&#160;</font>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td align=middle>

	<table border=0 width=65% bgcolor="#1FCBCB" cellpadding=5 >
	<tr><td>

		<table border=0 bgcolor="#9AC6CB" width=100% cellspacing=0>
		<tr><td>
		<font size=1>&#160;</font>
		</td></tr>

		<tr><td align=middle>
		<? echo $page_export[$_SESSION ["lang"]][3]; ?>
		</td></tr>

		<tr><td>
		<font size=1>&#160;</font>
		</td></tr>

		<tr><td width=40% align=middle>
		<select name="export">
		<option value=""></option>

		<?
		
		if (isset ($_SESSION ["base_mysql"])) {

		$connect=@mysql_connect($_SESSION ["base_mysql"], $_SESSION ["user_mysql"], $_SESSION ["password_mysql"])
		or die($page_export[$_SESSION ["lang"]][0]);

		@mysql_select_db ($_SESSION ["nom_base_mysql"]);

		$requete=@mysql_query ("select auto_inc, mail from $login");

		$nbre_lignes=@mysql_num_rows ($requete);

		for ($a=0;$a<$nbre_lignes;$a++) {
		$tri=@mysql_fetch_row ($requete);
		echo "<option value=\"$tri[0]\">$tri[1]</option>";
		}

		@mysql_close ($connect);
		
		} else {

		if (!isset ($_GET ["auth"])) {

		$connect_ldap=@ldap_connect ($_SESSION ["annuaire_ldap"], $_SESSION ["port_ldap"])
		or die ($page_export[$_SESSION ["lang"]][1]);

		$bind_dn = $_SESSION ["bind_dn"];
		$carnet_adresse = $_SESSION ["carnet_adresse"];
		$bind_adresses = $_SESSION ["bind_adresses"];

		//Chemin des utilisateurs et des carnets d'adresses
		$chemin_login="cn=$login,$bind_dn";
		$chemin_carnet_adresses="ou=$carnet_adresse,$bind_adresses";

		if (@ldap_bind($connect_ldap, $chemin_login, $_SESSION ["password"])!=false) {
		} else {

		@ldap_set_option($connect_ldap,LDAP_OPT_PROTOCOL_VERSION,3);

			if (@ldap_bind($connect_ldap, $chemin_login, $_SESSION ["password"])!=false) {
			} else {
			echo "<tr><td colspan=2 align=middle>\n".$page_export[$_SESSION ["lang"]][4]."\n</td></tr>";
			}
		}

		$cherche=@ldap_search($connect_ldap, "ou=rep_$login,$chemin_carnet_adresses", "(sn=*)", array (mail));
		$info=@ldap_get_entries($connect_ldap, $cherche);

		for ($b=0;$b<count ($info)-1;$b++) {
		echo "<option value=\"".$info[$b][mail][0]."\">".$info[$b][mail][0]."</option>";
		}

		@ldap_close ($connect_ldap);
		}
		}

		?>

		</select>
		</td></tr>

		<tr><td>
		<font size=1>&#160;</font>
		</td></tr>

		<tr><td align=middle>
		<input type="submit" value="<? echo $page_export[$_SESSION ["lang"]][5]; ?>">
		</td></tr>
		
		<?

		if (isset ($_GET ["envoi"])) {
		echo "<tr><td>\n<font size=1>&#160;</font>\n</td></tr>";
		echo "<tr><td align=middle>\n".$page_export[$_SESSION ["lang"]][6]."".
		"<a href=\"#\" onClick=\"open('../gestion_messages/nouveau_message.php?carte=1',".
		"'', 'height=550, width=650, scrollbars=yes, resizable=yes')\">".
		"".$page_export[$_SESSION ["lang"]][7]."</a>\n</td></tr>";
		echo "<tr><td>\n<font size=1>&#160;</font>\n</td></tr>";
		} elseif (isset ($_GET ["auth"])) {
		echo "<tr><td align=middle>\n".$page_export[$_SESSION ["lang"]][8]."\n</td></tr>";
		}

		?>

		</table>

	</td></tr>
	</table>
	
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td bgcolor="#1FCBCB">
<br>
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td align=middle bgcolor="#1FCBCB">
<font size=5><b><u>R-MAIL</u></b></font>
</td></tr>
</table>

</form>
</body>
</html>
